==> jc-1.4.0.tar.gz: javax/print/attribute/standard/NumberOfDocuments.h <==
// public final class javax.print.attribute.standard.NumberOfDocuments

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax
// @dep_class 4716882c3b09ef11 javax_print_attribute_standard_NumberOfDocuments

// header file dependencies
// @dep_header javax_print_attribute_IntegerSyntax

#include "javax/print/attribute/IntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_NumberOfDocuments_H_
#define _JC_javax_print_attribute_standard_NumberOfDocuments_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs	_jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs	_jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$refs	_jc_javax_print_attribute_standard_NumberOfDocuments$refs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs	_jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$object	_jc_javax_print_attribute_standard_NumberOfDocuments$object;

typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct	_jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_NumberOfDocuments$vmethods	_jc_javax_print_attribute_standard_NumberOfDocuments$vmethods;
typedef const struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtable	_jc_javax_print_attribute_standard_NumberOfDocuments$vtable;
typedef const struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtype	_jc_javax_print_attribute_standard_NumberOfDocuments$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24NumberOfDocuments;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct _jc_javax_print_attribute_standard_NumberOfDocuments$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_NumberOfDocuments$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *, jint);

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_NumberOfDocuments$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_NumberOfDocuments$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_NumberOfDocuments$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_NumberOfDocuments$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_NumberOfDocuments$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_NumberOfDocuments$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_NumberOfDocuments$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_NumberOfDocuments$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
	_jc_javax_print_attribute_standard_NumberOfDocuments$vmethods	javax_print_attribute_standard_NumberOfDocuments;
};

// Vtype
struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_NumberOfDocuments$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$refs {
    _jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs	javax_print_attribute_standard_NumberOfDocuments;
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
    _jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs	javax_print_attribute_standard_NumberOfDocuments;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_NumberOfDocuments$object {
	_jc_javax_print_attribute_standard_NumberOfDocuments$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_NumberOfDocuments$vtype	*vtype;
	_jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_NumberOfDocuments$vtype _jc_javax_print_attribute_standard_NumberOfDocuments$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_NumberOfDocuments, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_NumberOfDocuments$class_object;

#endif	/* _JC_javax_print_attribute_standard_NumberOfDocuments_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/NumberOfDocuments.h <==
// public final class javax.print.attribute.standard.NumberOfDocuments

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 18f59a31666d35f javax_print_attribute_IntegerSyntax
// @dep_class 4716882c3b09ef11 javax_print_attribute_standard_NumberOfDocuments

// header file dependencies
// @dep_header javax_print_attribute_IntegerSyntax

#include "javax/print/attribute/IntegerSyntax.h"

#ifndef _JC_javax_print_attribute_standard_NumberOfDocuments_H_
#define _JC_javax_print_attribute_standard_NumberOfDocuments_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs	_jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs	_jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$refs	_jc_javax_print_attribute_standard_NumberOfDocuments$refs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs	_jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs;
typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$object	_jc_javax_print_attribute_standard_NumberOfDocuments$object;

typedef struct _jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct	_jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_NumberOfDocuments$vmethods	_jc_javax_print_attribute_standard_NumberOfDocuments$vmethods;
typedef const struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtable	_jc_javax_print_attribute_standard_NumberOfDocuments$vtable;
typedef const struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtype	_jc_javax_print_attribute_standard_NumberOfDocuments$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24NumberOfDocuments;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_NumberOfDocuments$fields_struct _jc_javax_print_attribute_standard_NumberOfDocuments$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_NumberOfDocuments$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_standard_NumberOfDocuments$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_NumberOfDocuments$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_NumberOfDocuments$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_NumberOfDocuments$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_standard_NumberOfDocuments$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_NumberOfDocuments$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_NumberOfDocuments$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_NumberOfDocuments$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_NumberOfDocuments$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_IntegerSyntax$vmethods	javax_print_attribute_IntegerSyntax;
	_jc_javax_print_attribute_standard_NumberOfDocuments$vmethods	javax_print_attribute_standard_NumberOfDocuments;
};

// Vtype
struct _jc_javax_print_attribute_standard_NumberOfDocuments$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_NumberOfDocuments$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$refs {
    _jc_javax_print_attribute_standard_NumberOfDocuments$sub_refs	javax_print_attribute_standard_NumberOfDocuments;
    _jc_javax_print_attribute_IntegerSyntax$sub_refs	javax_print_attribute_IntegerSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_IntegerSyntax$sub_nonrefs	javax_print_attribute_IntegerSyntax;
    _jc_javax_print_attribute_standard_NumberOfDocuments$sub_nonrefs	javax_print_attribute_standard_NumberOfDocuments;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_NumberOfDocuments$object {
	_jc_javax_print_attribute_standard_NumberOfDocuments$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_NumberOfDocuments$vtype	*vtype;
	_jc_javax_print_attribute_standard_NumberOfDocuments$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_NumberOfDocuments$vtype _jc_javax_print_attribute_standard_NumberOfDocuments$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_NumberOfDocuments, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_NumberOfDocuments$class_object;

#endif	/* _JC_javax_print_attribute_standard_NumberOfDocuments_H_ */
